# BIAImage

This class represents the abstract concept of an image. Images are generated by acquisition by instruments.  Examples:  * A single plane bright-field image of a bacterium. * A confocal fluorescence image of cells, with two channels. * A volume EM stack of a cell.  Images are distinct from their representation as files, since the same image can be represented in different file formats and in some cases different file structures.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**attributes** | **object** |          When annotations are applied, the ones that have a key different than an object attribute (so they don&#39;t overwrite it) get saved here.      | [optional] 
**annotations_applied** | **bool** |          This acts as a dirty flag, with the purpose of telling apart objects that had some fields overwritten by applying annotations (so should be rejected when writing), and those that didn&#39;t.      | [optional] [default to False]
**annotations** | [**List[ImageAnnotation]**](ImageAnnotation.md) |  | [optional] [default to []]
**context** | **str** |  | [optional] [default to 'https://raw.githubusercontent.com/BioImage-Archive/bia-integrator/main/api/src/models/jsonld/1.0/ImageContext.jsonld']
**uuid** | **str** |  | 
**version** | **int** |  | 
**model** | [**ModelMetadata**](ModelMetadata.md) |  | [optional] 
**study_uuid** | **str** |  | 
**original_relpath** | **str** |  | 
**name** | **str** |  | [optional] 
**dimensions** | **str** |  | [optional] 
**representations** | [**List[BIAImageRepresentation]**](BIAImageRepresentation.md) |  | [optional] [default to []]
**alias** | [**BIAImageAlias**](BIAImageAlias.md) |  | [optional] 
**image_acquisitions_uuid** | **List[str]** | Context in which the image was acquired. This list often has one item, but it can occasionally have more (e.g. for multimodal imaging) | [optional] [default to []]

## Example

```python
from bia_integrator_api.models.bia_image import BIAImage

# TODO update the JSON string below
json = "{}"
# create an instance of BIAImage from a JSON string
bia_image_instance = BIAImage.from_json(json)
# print the JSON string representation of the object
print BIAImage.to_json()

# convert the object into a dict
bia_image_dict = bia_image_instance.to_dict()
# create an instance of BIAImage from a dict
bia_image_form_dict = bia_image.from_dict(bia_image_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


